@@ -49,7 +49,7 @@ def test_json_pdtable():
     ]
     pandas_pdtab = None
     # with io.StringIO(csv_src) as fh:
-    g = parse_blocks(cell_rows, **{"origin": '"types1.csv" row 1'}, fixer=custom_test_fixer)
+    g = parse_blocks(cell_rows, **{"origin": '"types1.csv" row 1'}, fixer=custom_test_fixer())
     for tp, tab in g:
         pandas_pdtab = tab
     # fmt: off
@@ -69,7 +69,7 @@ def test_json_pdtable():
     }
     # fmt: on
 
-    json_pdtab = json_data_to_table(table_json_data, fixer=custom_test_fixer)
+    json_pdtab = json_data_to_table(table_json_data, fixer=custom_test_fixer())
     assert pandas_pdtab.equals(json_pdtab)
 
 
@@ -91,7 +91,7 @@ def test_json_data_to_pdtable():
         ["goose", 2, 9, 0],
     ]
 
-    table_from_cell_grid = make_table(lines_target, fixer=custom_test_fixer)
+    table_from_cell_grid = make_table(lines_target, fixer=custom_test_fixer())
 
     # Make an identical table, but starting from JSON
 
@@ -112,12 +112,12 @@ def test_json_data_to_pdtable():
     }
     # fmt: on
 
-    table_from_json = json_data_to_table(table_json_data, fixer=custom_test_fixer)
+    table_from_json = json_data_to_table(table_json_data, fixer=custom_test_fixer())
     assert table_from_cell_grid.equals(table_from_json)
 
     # Round trip
     table_json_data_back = table_to_json_data(table_from_json)
-    table_from_json_round_trip = json_data_to_table(table_json_data_back, fixer=custom_test_fixer)
+    table_from_json_round_trip = json_data_to_table(table_json_data_back, fixer=custom_test_fixer())
     assert table_from_cell_grid.equals(table_from_json_round_trip)
 
 
@@ -150,7 +150,7 @@ def test_fat():
         with open(input_dir() / fn, "r") as fh:
             cell_rows = (line.rstrip("\n").split(";") for line in fh)
             g = parse_blocks(
-                cell_rows, **{"origin": f'"{fn}"', "to": "jsondata"}, fixer=custom_test_fixer
+                cell_rows, **{"origin": f'"{fn}"', "to": "jsondata"}, fixer=custom_test_fixer()
             )
 
             for tp, tt in g:
@@ -236,7 +236,7 @@ def test_make_table_json_data__empty_table():
         ["text", "-", "kg", "onoff"]
     ]
     # parse the table to a jsondata
-    table_json_data = make_table_json_data(lines_target, 'farm_types1.csv', fixer=custom_test_fixer)
+    table_json_data = make_table_json_data(lines_target, 'farm_types1.csv', fixer=custom_test_fixer())
 
     exp_table_json_data = {
       "name": "farm_types1",
@@ -256,6 +256,6 @@ def test_make_table_json_data__empty_table():
     assert table_json_data == exp_table_json_data
 
     # and json with empty values can be created into table
-    table_from_json = json_data_to_table(table_json_data, fixer=custom_test_fixer)
+    table_from_json = json_data_to_table(table_json_data, fixer=custom_test_fixer())
     table_from_lines = make_table(lines_target, fixer=custom_test_fixer)
     assert table_from_lines.equals(table_from_json)
